/* ***** BEGIN LICENSE BLOCK *****
 * FW4SPL - Copyright (C) IRCAD, 2009-2016.
 * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
 * published by the Free Software Foundation.
 * ****** END LICENSE BLOCK ****** */

#include <string>

#include <fwCore/base.hpp>

#include <fwRuntime/ConfigurationElement.hpp>
#include <fwRuntime/operations.hpp>

#include <fwServices/macros.hpp>


#include "fwRender/IRender.hpp"

namespace fwRender
{

//-----------------------------------------------------------------------------

IRender::IRender() noexcept
{
}

//-----------------------------------------------------------------------------

IRender::~IRender() noexcept
{
}

//-----------------------------------------------------------------------------

}
